@@ -1,28 +1,31 @@
-#!/usr/bin/perl
+#!/usr/bin/perl -w
 #
 #
 # A Net::DRI example for .COOP : creation of contacts, hosts, domains, and deleting domain
 
-use utf8;
 use strict;
-use warnings;
 
 use Net::DRI;
-
+use DateTime::Duration;
+ 
 ## Fill these variables : your registrar id, password, and contact prefix
 my $CLID='';
 my $PASS='';
 my $CID_PREFIX=''; ## The registry mandates all contacts ID to start with a specific prefix, tied to your account
 
 
-my $dri=Net::DRI->new({cache_ttl=>10,logging=>'files'});
+my $dri=Net::DRI->new(10);
 
-my $ok=eval {
+eval {
 ############################################################################################################
-$dri->add_registry('DotCooperation',{clid=>$CLID});
+$dri->add_registry('COOP',{clid=>$CLID});
+
+my $file='results-'.time().'.log';
+open(my $fh,'>>',$file) || die $!;
+print "Dumping XML exchange to $file\n";
 
 ## This connects to .COOP server for tests : make sure you have local files key.pem and cert.pem
-my $rc=$dri->target('DotCooperation')->add_current_profile('profile1','epp',{ssl_key_file=>'./key.pem',ssl_cert_file=>'./cert.pem',ssl_ca_file=>'./cert.pem',client_login=>$CLID,client_password=>$PASS});
+my $rc=$dri->target('COOP')->new_current_profile('profile1','Net::DRI::Transport::Socket',[{log_fh=>$fh,defer=>0,socktype=>'ssl',remote_host=>'217.10.159.121',remote_port=>700,ssl_cipher_list=>'TLSv1',ssl_key_file=>'./key.pem',ssl_cert_file=>'./cert.pem',ssl_ca_file=>'./cert.pem',protocol_connection=>'Net::DRI::Protocol::EPP::Connection',protocol_version=>1,client_login=>$CLID,client_password=>$PASS}],'Net::DRI::Protocol::EPP::Extensions::COOP',[]);
 
 die($rc) unless $rc->is_success(); ## Here we catch all errors during setup of transport, such as authentication errors
 
@@ -76,13 +79,13 @@ foreach my $ns (qw/ns1.example.com ns2.example.com/)
 my $dom='toto-'.time().'.coop';
 $rc=$dri->domain_check($dom);
 print "$dom exists: ".($dri->get_info('exist')? 'YES' : 'NO')."\n";
-my $cs=$dri->local_object('contactset');
+my $cs=$dri->local_object('contactset')->new();
 $cs->set($c3,'registrant');
 $cs->set($c4,'billing');
 $cs->set($c4,'tech');
 $cs->set($c4,'admin');
 print "Attempting to create domain $dom\n";
-$rc=$dri->domain_create($dom,{pure_create=>1,duration=>$dri->local_object('duration',years => 2),ns=>$nso,contact=>$cs,auth=>{pw=>'whatever'}});
+$rc=$dri->domain_create_only($dom,{duration=>DateTime::Duration->new(years =>2),ns=>$nso,contact=>$cs,auth=>{pw=>'whatever'}});
 print "$dom created successfully:".($rc->is_success()? 'YES' : 'NO')."\n";
 
 $rc=$dri->domain_check($dom);
@@ -90,7 +93,7 @@ print "$dom does exists now: ".($dri->get_info('exist')? 'YES' : 'NO')."\n";
 $rc=$dri->domain_info($dom);
 print "$dom domain_info: ".($rc->is_success()? 'YES' : 'NO')."\n";
 
-$rc=$dri->domain_delete($dom,{pure_delete => 1});
+$rc=$dri->domain_delete_only($dom);
 print "$dom domain_delete: ".($rc->is_success()? 'YES' : 'NO')."\n";
 
 $rc=$dri->contact_delete($c3);
@@ -104,18 +107,18 @@ print 'Contact4 deleted successfully: '.($rc->is_success()? 'YES' : 'NO')."\n";
 
 
 $dri->end();
+close($fh);
 };
 
-if (! $ok)
+if ($@)
 { 
- my $err=$@;
  print "\n\nAn EXCEPTION happened !\n";
- if (ref $err)
+ if (ref($@))
  {
-  $err->print();
+  $@->print();
  } else
  {
-  print $err;
+  print($@);
  }
 } else
 {
