@@ -1,7 +1,6 @@
 ## Domain Registry Interface, .INFO policies
 ##
-## Copyright (c) 2006-2009 Rony Meyer <perl@spot-light.ch>. All rights reserved.
-##           (c) 2010,2011 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
+## Copyright (c) 2006 Rony Meyer <perl@spot-light.ch>. All rights reserved.
 ##
 ## This file is part of Net::DRI
 ##
@@ -11,16 +10,17 @@
 ## (at your option) any later version.
 ##
 ## See the LICENSE file that comes with this distribution for more details.
+#
+# 
+#
 ####################################################################################################
 
 package Net::DRI::DRD::INFO;
 
 use strict;
-use warnings;
-
 use base qw/Net::DRI::DRD/;
 
-use DateTime::Duration;
+our $VERSION=do { my @r=(q$Revision: 1.1 $=~/\d+/g); sprintf("%d".".%02d" x $#r, @r); };
 
 =pod
 
@@ -50,8 +50,7 @@ Patrick Mevzek, E<lt>netdri@dotandco.comE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2006-2009 Rony Meyer <perl@spot-light.ch>.
-          (c) 2010,2011 Patrick Mevzek <netdri@dotandco.com>.
+Copyright (c) 2006 Rony Meyer <perl@spot-light.ch>.
 All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
@@ -67,11 +66,13 @@ See the LICENSE file that comes with this distribution for more details.
 
 sub new
 {
- my $class=shift;
+ my $proto=shift;
+ my $class=ref($proto) || $proto;
+
  my $self=$class->SUPER::new(@_);
  $self->{info}->{host_as_attr}=0;
- $self->{info}->{contact_i18n}=2; ## INT only
- $self->{info}->{check_limit}=38; ## Upper limit computed to that XML stream length is < 4096 bytes
+
+ bless($self,$class);
  return $self;
 }
 
@@ -79,15 +80,21 @@ sub periods  { return map { DateTime::Duration->new(years => $_) } (1..10); }
 sub name     { return 'INFO'; }
 sub tlds     { return ('info'); }
 sub object_types { return ('domain','contact','ns'); }
-sub profile_types { return qw/epp whois/; }
+
+sub transport_protocol_compatible
+{
+ my ($self,$to,$po)=@_;
+ my $pn=$po->name();
+ my $pv=$po->version();
+ my $tn=$to->name();
+
+ return 1 if (($pn eq 'EPP') && ($tn eq 'socket_inet'));
+ return;
+}
 
 sub transport_protocol_default
 {
- my ($self,$type)=@_;
- 
- return ('Net::DRI::Transport::Socket',{},'Net::DRI::Protocol::EPP::Extensions::Afilias',{})               if $type eq 'epp';
- return ('Net::DRI::Transport::Socket',{remote_host=>'whois.afilias.info'},'Net::DRI::Protocol::Whois',{}) if $type eq 'whois';
- return;
+ return ('Net::DRI::Transport::Socket','Net::DRI::Protocol::EPP');
 }
 
 ####################################################################################################
@@ -95,10 +102,26 @@ sub transport_protocol_default
 sub verify_name_domain
 {
  my ($self,$ndr,$domain,$op)=@_;
- return $self->_verify_name_rules($domain,$op,{check_name => 1,
-                                               my_tld => 1,
-                                               icann_reserved => 1,
-                                              });
+ ($domain,$op)=($ndr,$domain) unless (defined($ndr) && $ndr && (ref($ndr) eq 'Net::DRI::Registry'));
+
+ my $r=$self->SUPER::check_name($domain,1);
+ return $r if ($r);
+ return 10 unless $self->is_my_tld($domain);
+ return 11 if Net::DRI::DRD::ICANN::is_reserved_name($domain,$op);
+
+ return 0;
+}
+
+sub domain_operation_needs_is_mine
+{
+ my ($self,$ndr,$domain,$op)=@_;
+ ($domain,$op)=($ndr,$domain) unless (defined($ndr) && $ndr && (ref($ndr) eq 'Net::DRI::Registry'));
+
+ return unless defined($op);
+
+ return 1 if ($op=~m/^(?:renew|update|delete)$/);
+ return 0 if ($op eq 'transfer');
+ return;
 }
 
 ####################################################################################################
