@@ -1,6 +1,6 @@
 ## Domain Registry Interface, .MOBI policies
 ##
-## Copyright (c) 2006-2011 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
+## Copyright (c) 2006 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
 ##
 ## This file is part of Net::DRI
 ##
@@ -10,16 +10,17 @@
 ## (at your option) any later version.
 ##
 ## See the LICENSE file that comes with this distribution for more details.
+#
+# 
+#
 ####################################################################################################
 
 package Net::DRI::DRD::MOBI;
 
 use strict;
-use warnings;
-
 use base qw/Net::DRI::DRD/;
 
-use DateTime::Duration;
+our $VERSION=do { my @r=(q$Revision: 1.1 $=~/\d+/g); sprintf("%d".".%02d" x $#r, @r); };
 
 =pod
 
@@ -49,7 +50,7 @@ Patrick Mevzek, E<lt>netdri@dotandco.comE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2006-2011 Patrick Mevzek <netdri@dotandco.com>.
+Copyright (c) 2006 Patrick Mevzek <netdri@dotandco.com>.
 All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
@@ -65,10 +66,13 @@ See the LICENSE file that comes with this distribution for more details.
 
 sub new
 {
- my $class=shift;
+ my $proto=shift;
+ my $class=ref($proto) || $proto;
+
  my $self=$class->SUPER::new(@_);
  $self->{info}->{host_as_attr}=0;
- $self->{info}->{contact_i18n}=2; ## INT only
+
+ bless($self,$class);
  return $self;
 }
 
@@ -76,14 +80,45 @@ sub periods  { return map { DateTime::Duration->new(years => $_) } (1..10); }
 sub name     { return 'MOBI'; }
 sub tlds     { return ('mobi'); }
 sub object_types { return ('domain','contact','ns'); }
-sub profile_types { return qw/epp whois/; }
+
+sub transport_protocol_compatible
+{
+ my ($self,$to,$po)=@_;
+ my $pn=$po->name();
+ my $tn=$to->name();
+
+ return 1 if (($pn eq 'EPP') && ($tn eq 'socket_inet'));
+ return;
+}
 
 sub transport_protocol_default
 {
- my ($self,$type)=@_;
+ return ('Net::DRI::Transport::Socket','Net::DRI::Protocol::EPP::Extensions::MOBI');
+}
 
- return ('Net::DRI::Transport::Socket',{},'Net::DRI::Protocol::EPP::Extensions::MOBI',{})                         if $type eq 'epp';
- return ('Net::DRI::Transport::Socket',{remote_host=>'whois.dotmobiregistry.net'},'Net::DRI::Protocol::Whois',{}) if $type eq 'whois';
+####################################################################################################
+
+sub verify_name_domain
+{
+ my ($self,$ndr,$domain)=@_;
+ $domain=$ndr unless (defined($ndr) && $ndr && (ref($ndr) eq 'Net::DRI::Registry'));
+
+ my $r=$self->SUPER::check_name($domain,1);
+ return $r if ($r);
+ return 10 unless $self->is_my_tld($domain);
+
+ return 0;
+}
+
+sub domain_operation_needs_is_mine
+{
+ my ($self,$ndr,$domain,$op)=@_;
+ ($domain,$op)=($ndr,$domain) unless (defined($ndr) && $ndr && (ref($ndr) eq 'Net::DRI::Registry'));
+
+ return unless defined($op);
+
+ return 1 if ($op=~m/^(?:renew|update|delete)$/);
+ return 0 if ($op eq 'transfer');
  return;
 }
 
