@@ -1,6 +1,6 @@
 ## Domain Registry Interface, EPP Contact commands (RFC3733)
 ##
-## Copyright (c) 2005,2006 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
+## Copyright (c) 2005,2006,2007 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
 ##
 ## This file is part of Net::DRI
 ##
@@ -26,7 +26,7 @@ use Net::DRI::Protocol::EPP::Core::Status;
 
 use DateTime::Format::ISO8601;
 
-our $VERSION=do { my @r=(q$Revision: 1.8 $=~/\d+/g); sprintf("%d".".%02d" x $#r, @r); };
+our $VERSION=do { my @r=(q$Revision: 1.10 $=~/\d+/g); sprintf("%d".".%02d" x $#r, @r); };
 
 =pod
 
@@ -56,7 +56,7 @@ Patrick Mevzek, E<lt>netdri@dotandco.comE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2005,2006 Patrick Mevzek <netdri@dotandco.com>.
+Copyright (c) 2005,2006,2007 Patrick Mevzek <netdri@dotandco.com>.
 All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
@@ -319,8 +319,7 @@ sub parse_disclose ## RFC 3733 2.9
   if ($name=~m/^(name|org|addr)$/)
   {
    my $t=$n->getAttribute('type');
-   $tmp{$1}=$flag;
-   $tmp{"${1}_${t}"}=$flag;
+   $tmp{$1.'_'.$t}=$flag;
   } elsif ($name=~m/^(voice|fax|email)$/)
   {
    $tmp{$1}=$flag;
