@@ -1,6 +1,6 @@
 ## Domain Registry Interface, EPP Domain commands (RFC3731)
 ##
-## Copyright (c) 2005,2006 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
+## Copyright (c) 2005,2006,2007 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
 ##
 ## This file is part of Net::DRI
 ##
@@ -28,7 +28,7 @@ use Net::DRI::Protocol::EPP::Core::Status;
 
 use DateTime::Format::ISO8601;
 
-our $VERSION=do { my @r=(q$Revision: 1.9 $=~/\d+/g); sprintf("%d".".%02d" x $#r, @r); };
+our $VERSION=do { my @r=(q$Revision: 1.11 $=~/\d+/g); sprintf("%d".".%02d" x $#r, @r); };
 
 =pod
 
@@ -58,7 +58,7 @@ Patrick Mevzek, E<lt>netdri@dotandco.comE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2005,2006 Patrick Mevzek <netdri@dotandco.com>.
+Copyright (c) 2005,2006,2007 Patrick Mevzek <netdri@dotandco.com>.
 All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
@@ -418,7 +418,7 @@ sub build_ns
    my ($n,$r4,$r6)=$ns->get_details($i);
    my @h;
    push @h,['domain:hostName',$n];
-   if (($n=~m/\S+\.${domain}$/i) || (lc($n) eq lc($domain)))
+   if (($n=~m/\S+\.${domain}$/i) || (lc($n) eq lc($domain)) || ($asattr==2))
    {
     push @h,map { ['domain:hostAddr',$_,{ip=>'v4'}] } @$r4 if @$r4;
     push @h,map { ['domain:hostAddr',$_,{ip=>'v6'}] } @$r6 if @$r6;
