@@ -1,6 +1,6 @@
 ## Domain Registry Interface, EPP Registry messages commands (RFC3730)
 ##
-## Copyright (c) 2006 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
+## Copyright (c) 2006,2007 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
 ##
 ## This file is part of Net::DRI
 ##
@@ -24,7 +24,7 @@ use DateTime::Format::ISO8601;
 use Net::DRI::Exception;
 use Net::DRI::Util;
 
-our $VERSION=do { my @r=(q$Revision: 1.4 $=~/\d+/g); sprintf("%d".".%02d" x $#r, @r); };
+our $VERSION=do { my @r=(q$Revision: 1.5 $=~/\d+/g); sprintf("%d".".%02d" x $#r, @r); };
 
 =pod
 
@@ -54,7 +54,7 @@ Patrick Mevzek, E<lt>netdri@dotandco.comE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2006 Patrick Mevzek <netdri@dotandco.com>.
+Copyright (c) 2006,2007 Patrick Mevzek <netdri@dotandco.com>.
 All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
@@ -103,44 +103,55 @@ sub parse_poll
  return unless $mes->is_success();
 
  my $msgid=$mes->msg_id();
- $rinfo->{message}->{session}->{last_id}=$msgid;
- my $rd=$rinfo->{message}->{$msgid}; ## already partially filled by Message::parse()
-
- my ($totype,$toaction,$toname); ## $toaction will remain undef, but could be $haction if only one
- my %info;
- my $h=$po->commands();
-
- while (my ($htype,$hv)=each(%$h))
+ my $rd={};
+ if (defined($msgid) && $msgid)
  {
-  while (my ($haction,$hv2)=each(%$hv))
+  $rinfo->{message}->{session}->{last_id}=$msgid;
+  $rd=$rinfo->{message}->{$msgid}; ## already partially filled by Message::parse()
+ }
+
+ if ($mes->errcode() == 1301 && (defined($mes->node_resdata()) || defined($mes->node_extension()))) ## there was really a message with some content
+ {
+  my ($totype,$toaction,$toname); ## $toaction will remain undef, but could be $haction if only one
+  my %info;
+  my $h=$po->commands();
+ 
+  while (my ($htype,$hv)=each(%$h))
   {
-   next if (($htype eq 'message') && ($haction eq 'retrieve')); ## calling myself here would be a very bad idea !
-   foreach my $t (@$hv2)
+   while (my ($haction,$hv2)=each(%$hv))
    {
-    my $pf=$t->[1];
-    next unless (defined($pf) && (ref($pf) eq 'CODE'));
-    $pf->($po,$totype,$toaction,$toname,\%info);
-    next unless keys(%info);
-    next if defined($toname);
-    Net::DRI::Exception::err_assert('EPP::parse_poll can not handle multiple types !') unless (keys(%info)==1);
-    $totype=(keys(%info))[0];
-    Net::DRI::Exception::err_assert('EPP::parse_poll can not handle multiple names !') unless (keys(%{$info{$totype}})==1); ## this may happen for check_multi !
-    $toname=(keys(%{$info{$totype}}))[0];
-    $info{$totype}->{$toname}->{name}=$toname;
+    next if (($htype eq 'message') && ($haction eq 'retrieve')); ## calling myself here would be a very bad idea !
+    foreach my $t (@$hv2)
+    {
+     my $pf=$t->[1];
+     next unless (defined($pf) && (ref($pf) eq 'CODE'));
+     $pf->($po,$totype,$toaction,$toname,\%info);
+     next unless keys(%info);
+     next if defined($toname);
+     Net::DRI::Exception::err_assert('EPP::parse_poll can not handle multiple types !') unless (keys(%info)==1);
+     $totype=(keys(%info))[0];
+     Net::DRI::Exception::err_assert('EPP::parse_poll can not handle multiple names !') unless (keys(%{$info{$totype}})==1); ## this may happen for check_multi !
+     $toname=(keys(%{$info{$totype}}))[0];
+     $info{$totype}->{$toname}->{name}=$toname;
+    }
    }
   }
- }
- Net::DRI::Exception::err_assert('EPP::parse_poll was not able to parse anything, please report !') unless $toname;
+  Net::DRI::Exception::err_assert('EPP::parse_poll was not able to parse anything, please report !') unless $toname;
 
- ## Copy %info into $rd someway
- $rd->{object_type}=$totype;
- $rd->{object_id}=$toname; ## this has to be taken broadly, it is in fact a name for domains and hosts
- while(my ($k,$v)=each(%{$info{$totype}->{$toname}}))
- {
-  $rd->{$k}=$v;
+  ## Copy %info into $rd someway
+  $rd->{object_type}=$totype;
+  $rd->{object_id}=$toname; ## this has to be taken broadly, it is in fact a name for domains and hosts
+  while(my ($k,$v)=each(%{$info{$totype}->{$toname}}))
+  {
+   $rd->{$k}=$v;
+  }
  }
 
  ## TODO : optionnally, offer to merge this new information with already existing cache information
+ ## in order to be able to do:
+ ## $dri->get_info('clID')
+ ## instead of currently:
+ ## $dri->get_info('clID','message',$id)
 }
 
 ####################################################################################################
