@@ -1,7 +1,7 @@
 ## Domain Registry Interface, NIC.AT Contact extension
 ## Contributed by Michael Braunoeder from NIC.AT <mib@nic.at>
 ##
-## Copyright (c) 2006-2008,2010,2013,2016,2018,2019 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
+## Copyright (c) 2006,2007 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
 ##
 ## This file is part of Net::DRI
 ##
@@ -11,13 +11,18 @@
 ## (at your option) any later version.
 ##
 ## See the LICENSE file that comes with this distribution for more details.
+#
+# 
+#
 ####################################################################################################
 
 package Net::DRI::Protocol::EPP::Extensions::AT::Contact;
 
 use strict;
-use warnings;
-use feature 'state';
+
+our $VERSION=do { my @r=(q$Revision: 1.2 $=~/\d+/g); sprintf("%d".".%02d" x $#r, @r); };
+
+our $NS='http://www.nic.at/xsd/at-ext-contact-1.0';
 
 =pod
 
@@ -47,7 +52,7 @@ Patrick Mevzek, E<lt>netdri@dotandco.comE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2006-2008,2010,2013,2016,2018,2019 Patrick Mevzek <netdri@dotandco.com>.
+Copyright (c) 2006,2007 Patrick Mevzek <netdri@dotandco.com>.
 All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
@@ -64,66 +69,61 @@ See the LICENSE file that comes with this distribution for more details.
 sub register_commands
 {
  my ($class,$version)=@_;
- state $contact = {
-                   info   => [ undef, \&parse_info ],
-                   update => [ \&update, undef ],
-                   create => [ \&create, undef ],
-                  };
- state $commands = { 'contact' => $contact };
+ my %tmp=(
+                  info   => [ undef, \&parse_info ],
+                  update => [ \&update, undef ],
+                  create => [ \&create, undef ],
+         );
 
- return $commands;
+ return { 'contact' => \%tmp };
 }
 
-sub setup
-{
- my ($class,$po,$version)=@_;
- $po->ns({ 'at-ext-contact' => 'http://www.nic.at/xsd/at-ext-contact-1.0' });
- return;
-}
 
 sub parse_info
 {
  my ($po,$otype,$oaction,$oname,$rinfo)=@_;
  my $mes=$po->message();
 
- return unless $mes->is_success();
-
+ return unless ($mes->{errcode} eq "1000");
  my $c=$rinfo->{contact}->{$oname}->{self};
  $c->email(undef) if ($c->email() eq 'n/a');
 
- my $condata=$mes->get_extension('at-ext-contact', 'infData');
+ my $condata=$mes->get_content('infData',$NS,1);
  return unless $condata;
 
  my @options;
 
- my $el=$condata->getElementsByTagNameNS($mes->ns('at-ext-contact'), 'type');
+ my $el=$condata->getElementsByTagNameNS($NS,'type');
  my $type=$el? $el->get_node(1)->getFirstChild()->getData() : undef;
 
  $c->type($type) if (defined($type) && $type);
 # $rinfo->{contact}->{$oname}->{type}=$type if $type;
- return;
 }
 
 sub create
 {
  my ($epp,$contact,$rd)=@_;
+ my $mes=$epp->message();
 
  my $type=$contact->type();
- return unless defined $type;
+ return unless (defined($type));
 
- $epp->message()->command_extension('at-ext-contact', ['create', ['type', $type]]);
- return;
+ my $eid=$mes->command_extension_register('at-ext-contact:create','xmlns:at-ext-contact="'.$NS.'" xsi:schemaLocation="'.$NS.' at-ext-contact-1.0.xsd"');
+ $mes->command_extension($eid,['at-ext-contact:type',$type]);
 }
 
 sub update
 {
  my ($epp,$contact,$todo)=@_;
 
- my $type=$todo->set('info')->type();
- return unless defined $type;
+ my $mes=$epp->message();
+ my $newc=$todo->set('info');
 
- $epp->message()->command_extension('at-ext-contact', ['update', ['chg', ['type', $type]]]);
- return;
+ my $type=$newc->type();
+ return unless (defined($type));
+
+ my $eid=$mes->command_extension_register('at-ext-contact:update','xmlns:at-ext-contact="'.$NS.'" xsi:schemaLocation="'.$NS.' at-ext-contact-1.0.xsd"');
+ $mes->command_extension($eid,['at-ext-contact:chg',['at-ext-contact:type',$type]]);
 }
 
 ####################################################################################################
