@@ -1,6 +1,6 @@
 ## Domain Registry Interface, EPP IDN Language (EPP-IDN-Lang-Mapping.pdf)
 ##
-## Copyright (c) 2006,2008,2013,2016,2018-2019 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
+## Copyright (c) 2006 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
 ##
 ## This file is part of Net::DRI
 ##
@@ -10,17 +10,20 @@
 ## (at your option) any later version.
 ##
 ## See the LICENSE file that comes with this distribution for more details.
+#
+# 
+#
 ####################################################################################################
 
 package Net::DRI::Protocol::EPP::Extensions::VeriSign::IDNLanguage;
 
 use strict;
-use warnings;
-use feature 'state';
 
 use Net::DRI::Util;
 use Net::DRI::Exception;
 
+our $VERSION=do { my @r=(q$Revision: 1.2 $=~/\d+/g); sprintf("%d".".%02d" x $#r, @r); };
+
 =pod
 
 =head1 NAME
@@ -49,7 +52,7 @@ Patrick Mevzek, E<lt>netdri@dotandco.comE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2006,2008,2013,2016,2018-2019 Patrick Mevzek <netdri@dotandco.com>.
+Copyright (c) 2006 Patrick Mevzek <netdri@dotandco.com>.
 All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
@@ -61,22 +64,17 @@ See the LICENSE file that comes with this distribution for more details.
 
 =cut
 
+
 ####################################################################################################
 
 sub register_commands
 {
  my ($class,$version)=@_;
- state $cmds = { 'domain' => { 'create' => [ \&create, undef ] } };
+ my %tmp=(
+           create => [ \&create, undef ],
+         );
 
- return $cmds;
-}
-
-sub setup
-{
- my ($class,$po,$version)=@_;
- state $rns = { 'idnLang' => 'http://www.verisign.com/epp/idnLang-1.0' };
- $po->ns($rns);
- return;
+ return { 'domain' => \%tmp };
 }
 
 ####################################################################################################
@@ -86,14 +84,14 @@ sub setup
 sub create
 {
  my ($epp,$domain,$rd)=@_;
+ my $mes=$epp->message();
 
- return unless ($domain=~/^xn--/);
+ Net::DRI::Exception::usererr_insufficient_parameters('Language tag must be provided') unless (defined($rd) && (ref($rd) eq 'HASH') && exists($rd->{language}));
 
- Net::DRI::Exception::usererr_insufficient_parameters('Language tag must be provided') unless Net::DRI::Util::has_key($rd,'language');
  Net::DRI::Exception::usererr_invalid_parameters('IDN language tag must be of type XML schema language') unless Net::DRI::Util::xml_is_language($rd->{language});
 
- $epp->message()->command_extension('idnLang', ['tag', $rd->{language}]);
- return;
+ my $eid=$mes->command_extension_register('idnLang:tag','xmlns:idnLang="http://www.verisign.com/epp/idnLang-1.0" xsi:schemaLocation="http://www.verisign.com/epp/idnLang-1.0 idnLang-1.0.xsd"');
+ $mes->command_extension($eid,$rd->{language});
 }
 
 ####################################################################################################
